@@ -158,7 +158,9 @@ class Artifacts:
                 ArtifactEntry(path=data.get_path(name), local_path=local_path, size=size, digest=digest, status="ADD",
                               lfs_yn="", repo_tag="", type="TABLE", metadata=data.to_json(name), key=name))
         elif isinstance(data, Image):
+            data:Image = data
             assert_that(name).is_not_none()
+            # Image에 파일
             local_path = data.local_path
             digest = data.get_digest()
             size = data.get_size()
@@ -167,14 +169,16 @@ class Artifacts:
                               lfs_yn="", repo_tag="", type="IMAGE", metadata=data.to_json(name), key=name))
 
 
+            # Image에 대한 Json파일
             json_file_path = os.path.join(".", data.get_path(name))
             json_digest, json_size = data.file_dump(json_file_path, name)
 
             self.entry_list.append(
-                ArtifactEntry(path=data.get_path_json(name), local_path=json_file_path, size=size, digest=json_digest, status="ADD",
-                              lfs_yn="", repo_tag="", type="IMAGE", metadata=data.to_json(name), key=name+"_json"))
+                ArtifactEntry(path=data.get_path_json(name), local_path=json_file_path, size=json_size, digest=json_digest, status="ADD",
+                              lfs_yn="", repo_tag="", type="IMAGE", metadata=data.meta_json(name), key=name + "_json"))
 
         elif isinstance(data, Chart):
+            data : Chart = data
             assert_that(name).is_not_none()
             # TODO: local_path?
             local_path = os.path.join(".", data.get_path(name))
@@ -186,6 +190,8 @@ class Artifacts:
             if all(isinstance(n, Image) for n in data):    #Image 객체 배열일 경우
                 assert_that(name).is_not_none()
                 for index, n in enumerate(data):
+                    n : Image = n
+                    # Image에 파일
                     local_path = n.local_path
                     digest = n.get_digest()
                     size = n.get_size()
@@ -193,14 +199,14 @@ class Artifacts:
                         ArtifactEntry(path=n.get_path(key_name=name, is_list=True, index=index), local_path=local_path, size=size, digest=digest,
                                       status="ADD",
                                       lfs_yn="", repo_tag="", type="IMAGE", metadata=n.to_json(key_name=name, is_list=True, index=index), key=name))
-
+                    # Image에 대한 json 파일
                     json_file_path = os.path.join(".", n.get_path(name))
                     json_digest, json_size = n.file_dump(json_file_path, name)
 
                     self.entry_list.append(
-                        ArtifactEntry(path=n.get_path_json(name), local_path=json_file_path, size=size,
+                        ArtifactEntry(path=n.get_path_json(name), local_path=json_file_path, size=json_size,
                                       digest=json_digest, status="ADD",
-                                      lfs_yn="", repo_tag="", type="IMAGE", metadata=n.to_json(json_file_key), key=name+"_json"))
+                                      lfs_yn="", repo_tag="", type="IMAGE", metadata=n.meta_json(key_name=name, is_list=True, index=index), key=name + "_json"))
 
 
     def __add_file(self, data: Union[str], name: str = None, depth: int = 0) -> None:
