@@ -45,7 +45,7 @@ class Image(Media):
 
         # caption, boxes 처리
         self.caption: str = caption
-        self.boxes: Dict = None
+        self.boxes: BoundingBoxes = None
 
         if boxes:
             if isinstance(boxes, BoundingBoxes):
