@@ -30,15 +30,22 @@ def get_stub() -> ResourceStub:
     return stub
 
 grpc_host : str = "127.0.0.1:19051"
+use_grpc_tls : bool = False # GPRC의 tls(ssl) 사용여부
 
-def set_grpc_host(grpc_host_: str) -> None:
+def set_grpc_host(grpc_host_: str, use_grpc_tls_=False) -> None:
     global grpc_host
+    global use_grpc_tls
     grpc_host = grpc_host_
+    use_grpc_tls = use_grpc_tls_
 
 def get_grpc_host() -> str:
     global grpc_host
     return grpc_host
 
+def get_use_grpc_tls() -> bool:
+    global use_grpc_tls
+    return use_grpc_tls
+
 http_host = "127.0.0.1:9011"
 
 def set_http_host(http_host_: str) -> None:
@@ -333,11 +340,16 @@ def login(key: str) -> (bool, str):
     if rsp["result"] == "success":
 
         grpc_url = get_grpc_host()
-
+        use_grpc_tls = get_use_grpc_tls()
         if grpc_url is None:
             grpc_url = rsp["grpcHost"]
         # grpc stub 생성
-        channel = grpc.secure_channel(grpc_url, grpc.ssl_channel_credentials(()))
+        if use_grpc_tls:
+            channel_opt = ()
+            channel_opt += (('grpc.ssl_target_name_override', 'bokchi.com'),)
+            channel = grpc.secure_channel(grpc_url, grpc.ssl_channel_credentials(), channel_opt)
+        else:
+            channel = grpc.insecure_channel(grpc_url)
         stub = ResourceStub(channel)
         set_stub(stub)
     if rsp["result"] == "success":
