@@ -59,24 +59,22 @@ def visualize(obj: Union[Chart, Table, Image]) -> None:
                     fig.add_annotation(
                         x=box["position"]["minX"],
                         xanchor='left',
-                        y=box["position"]["minY"] - 18,
+                        y=box["position"]["minY"] - 12,
                         yanchor='top',
                         text=box["caption"],
                         showarrow=False,
-                        height=25, font_color='white', bgcolor='black', )
+                        font_size=16, font_color='white', bgcolor='black', )
 
         # show image caption
         if obj.caption:
-            x_pos = obj.width / 2
-            y_pos = obj.height
-            fig.add_annotation(
-                x=x_pos,
-                xanchor='center',
-                y=y_pos - 20,
-                yanchor='middle',
-                text=obj.caption,
-                showarrow=False,
-                font_size=20, font_color='white', bgcolor='black')
+            fig.update_layout(
+                title={
+                    'text': f'<span style="font-size: 22px;">{obj.caption}</span>',
+                    'x': 0.5,
+                    'y':0.02,
+                },
+
+            )
         fig.show()
 
     def visualize_chart_common(obj: Chart):
