@@ -1,5 +1,6 @@
 from typing import Literal, Optional
-import torch
+from deepdriver.sdk.lib.lazyloader import LazyLoader
+torch = LazyLoader('deepdriver.lazy.torch', globals(), 'torch')
 
 from deepdriver.intergration.torch.torch import get_torch_log
 
